@@ -20,7 +20,7 @@ package Finance::Quote::AlphaVantage;
 
 require 5.005;
 
-our $VERSION = '1.45'; # VERSION
+our $VERSION = '1.46'; # VERSION
 
 use strict;
 use JSON qw( decode_json );
@@ -93,6 +93,7 @@ my %currencies_by_suffix = (
     '.BK'  => "THB",    # Thialand	Thailand Stock Exchange
     '.TH'  => "THB",    # 		??? From Asia.pm, (in Thai Baht)
     '.L'   => "GBP",    # United Kingdom	London
+    '.IL'  => "USD",    # United Kingdom	London USD*100
 );
 
 
@@ -134,8 +135,19 @@ sub alphavantage {
         my $code = $reply->code;
         my $desc = HTTP::Status::status_message($code);
         my $body = $reply->content;
+        if ($code != 200) {
+            $info{ $stock, 'success' } = 0;
+            $info{ $stock, 'errormsg' } = $desc;
+            next;
+        }
+
+        my $json_data;
+        eval {$json_data = JSON::decode_json $body};
+        if ($@) {
+            $info{ $stock, 'success' } = 0;
+            $info{ $stock, 'errormsg' } = $@;
+        }
 
-        my $json_data = JSON::decode_json $body;
         if ( !$json_data || $json_data->{'Error Message'} ) {
             $info{ $stock, 'success' } = 0;
             $info{ $stock, 'errormsg' } =
@@ -204,6 +216,15 @@ sub alphavantage {
                                                   0.01 );
                     }
                 }
+                # divide USD quotes by 100 if suffix is '.IL'
+                if ( ($suffix eq '.IL') && ($info{$stock,'currency'} eq 'USD') ) {
+                    foreach my $field ( $quoter->default_currency_fields ) {
+                        next unless ( $info{ $stock, $field } );
+                        $info{ $stock, $field } =
+                            $quoter->scale_field( $info{ $stock, $field },
+                                                  0.01 );
+                    }
+                }
             }
         }
         else {
